@@ -1,6 +1,6 @@
 package Sisimai::Lhost::MailRu;
 use parent 'Sisimai::Lhost';
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ sub inquire {
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.4
     my $class = shift;
     my $mhead = shift // return undef;
@@ -69,7 +69,6 @@ sub inquire {
     my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
-    my $localhost0 = '';    # (String) Local MTA
     my $v = undef;
 
     for my $e ( split("\n", $emailparts->[0]) ) {
@@ -142,16 +141,14 @@ sub inquire {
     }
     return undef unless $recipients;
 
+    # Get the name of the local MTA
+    # Received: from marutamachi.example.org (c192128.example.net [192.0.2.128])
+    my $receivedby = $mhead->{'received'} || [];
+    my $recvdtoken = Sisimai::RFC5322->received($receivedby->[-1]);
     my $p1 = -1; my $p2 = -1;
-    if( scalar $mhead->{'received'}->@* ) {
-        # Get the name of local MTA
-        # Received: from marutamachi.example.org (c192128.example.net [192.0.2.128])
-        $p1 = index($mhead->{'received'}->[-1], 'from ');
-        $p2 = index($mhead->{'received'}->[-1], ' ', $p1 + 5);
-        $localhost0 = substr($mhead->{'received'}->[-1], $p1 + 5, $p2 - $p1 - 5) if $p1 > -1;
-    }
 
     for my $e ( @$dscontents ) {
+        # Check the error message, the rhost, the lhost, and the smtp command.
         if( exists $e->{'alterrors'} && $e->{'alterrors'} ) {
             # Copy alternative error message
             $e->{'diagnosis'} ||= $e->{'alterrors'};
@@ -170,17 +167,10 @@ sub inquire {
             # host neko.example.jp [192.0.2.222]: 550 5.1.1 <kijitora@example.jp>... User Unknown
             $p1 = index($e->{'diagnosis'}, 'host ');
             $p2 = index($e->{'diagnosis'}, ' ', $p1 + 5);
-            $e->{'rhost'} = substr($e->{'diagnosis'}, $p1 + 5, $p2 - $p1 - 5) if $p1 > -1;
-
-            unless( $e->{'rhost'} ) {
-                if( scalar $mhead->{'received'}->@* ) {
-                    # Get localhost and remote host name from Received header.
-                    my $r0 = $mhead->{'received'};
-                    $e->{'rhost'} = pop Sisimai::RFC5322->received($r0->[-1])->@*;
-                }
-            }
+            $e->{'rhost'}   = substr($e->{'diagnosis'}, $p1 + 5, $p2 - $p1 - 5) if $p1 > -1;
+            $e->{'rhost'} ||= $recvdtoken->[1];
         }
-        $e->{'lhost'} ||= $localhost0;
+        $e->{'lhost'} ||= $recvdtoken->[0];
 
         unless( $e->{'command'} ) {
             # Get the SMTP command name for the session
@@ -224,7 +214,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::MailRu - bounce mail parser class for C<@mail.ru>.
+Sisimai::Lhost::MailRu - bounce mail decoder class for @mail.ru L<https://mail.ru>.
 
 =head1 SYNOPSIS
 
@@ -232,8 +222,8 @@ Sisimai::Lhost::MailRu - bounce mail parser class for C<@mail.ru>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::MailRu parses a bounce email which created by C<@mail.ru>. Methods in the module are
-called from only Sisimai::Message.
+C<Sisimai::Lhost::MailRu> decodes a bounce email which created by @mail.ru L<https://mail.ru>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -245,8 +235,8 @@ C<description()> returns description string of this module.
 
 =head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<inquire()> method parses a bounced email and return results as a array reference. See Sisimai::Message
-for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
@@ -254,10 +244,11 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2023 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
 This software is distributed under The BSD 2-Clause License.
 
 =cut
+
