@@ -1,16 +1,16 @@
 package Sisimai::Lhost::MessageLabs;
 use parent 'Sisimai::Lhost';
-use feature ':5.10';
+use v5.26;
 use strict;
 use warnings;
 
-sub description { 'Symantec.cloud http://www.messagelabs.com' }
-sub make {
-    # Detect an error from MessageLabs.com
+sub description { 'Email Security (formerly Messaging Security): https://www.broadcom.com/products/cybersecurity/email' }
+sub inquire {
+    # Detect an error from Email Security (Formerly MessageLabs.com)
     # @param    [Hash] mhead    Message headers of a bounce email
     # @param    [String] mbody  Message body of a bounce email
     # @return   [Hash]          Bounce data list and message/rfc822 part
-    # @return   [Undef]         failed to parse or the arguments are missing
+    # @return   [undef]         failed to decode or the arguments are missing
     # @since v4.1.10
     my $class = shift;
     my $mhead = shift // return undef;
@@ -26,27 +26,25 @@ sub make {
     return undef unless index($mhead->{'subject'}, 'Mail Delivery Failure') == 0;
 
     state $indicators = __PACKAGE__->INDICATORS;
-    state $rebackbone = qr|^Content-Type:[ ]text/rfc822-headers|m;
+    state $boundaries = ['Content-Type: text/rfc822-headers'];
     state $startingof = { 'message' => ['Content-Type: message/delivery-status'] };
-    state $refailures = {
-        'userunknown'   => qr/(?:542 .+ Rejected|No such user)/,
-        'securityerror' => qr/Please turn on SMTP Authentication in your mail client/,
+    state $messagesof = {
+        'userunknown'   => ['542 ', ' Rejected', 'No such user'],
+        'securityerror' => ['Please turn on SMTP Authentication in your mail client'],
     };
 
-    require Sisimai::RFC1894;
     my $fieldtable = Sisimai::RFC1894->FIELDTABLE;
     my $permessage = {};    # (Hash) Store values of each Per-Message field
-
     my $dscontents = [__PACKAGE__->DELIVERYSTATUS];
-    my $emailsteak = Sisimai::RFC5322->fillet($mbody, $rebackbone);
+    my $emailparts = Sisimai::RFC5322->part($mbody, $boundaries);
     my $readcursor = 0;     # (Integer) Points the current cursor position
     my $recipients = 0;     # (Integer) The number of 'Final-Recipient' header
     my $v = undef;
     my $p = '';
 
-    for my $e ( split("\n", $emailsteak->[0]) ) {
-        # Read error messages and delivery status lines from the head of the email
-        # to the previous line of the beginning of the original message.
+    for my $e ( split("\n", $emailparts->[0]) ) {
+        # Read error messages and delivery status lines from the head of the email to the previous
+        # line of the beginning of the original message.
         unless( $readcursor ) {
             # Beginning of the bounce message or message/delivery-status part
             $readcursor |= $indicators->{'deliverystatus'} if index($e, $startingof->{'message'}->[0]) == 0;
@@ -93,8 +91,8 @@ sub make {
         } else {
             # Continued line of the value of Diagnostic-Code field
             next unless index($p, 'Diagnostic-Code:') == 0;
-            next unless $e =~ /\A[ \t]+(.+)\z/;
-            $v->{'diagnosis'} .= ' '.$1;
+            next unless index($e, ' ');
+            $v->{'diagnosis'} .= ' '.Sisimai::String->sweep($e);
         } # End of message/delivery-status
     } continue {
         # Save the current line for the next loop
@@ -104,18 +102,17 @@ sub make {
 
     for my $e ( @$dscontents ) {
         # Set default values if each value is empty.
-        $e->{'lhost'} ||= $permessage->{'rhost'};
         $e->{ $_ } ||= $permessage->{ $_ } || '' for keys %$permessage;
         $e->{'diagnosis'} = Sisimai::String->sweep($e->{'diagnosis'});
 
-        SESSION: for my $r ( keys %$refailures ) {
+        SESSION: for my $r ( keys %$messagesof ) {
             # Verify each regular expression of session errors
-            next unless $e->{'diagnosis'} =~ $refailures->{ $r };
+            next unless grep { index($e->{'diagnosis'}, $_) > -1 } $messagesof->{ $r }->@*;
             $e->{'reason'} = $r;
             last;
         }
     }
-    return { 'ds' => $dscontents, 'rfc822' => $emailsteak->[1] };
+    return { 'ds' => $dscontents, 'rfc822' => $emailparts->[1] };
 }
 
 1;
@@ -125,7 +122,8 @@ __END__
 
 =head1 NAME
 
-Sisimai::Lhost::MessageLabs - bounce mail parser class for C<MessageLabs>.
+Sisimai::Lhost::MessageLabs - bounce mail decode class for Email Security (formerly Messaging Security)
+L<https://www.broadcom.com/products/cybersecurity/email>
 
 =head1 SYNOPSIS
 
@@ -133,9 +131,10 @@ Sisimai::Lhost::MessageLabs - bounce mail parser class for C<MessageLabs>.
 
 =head1 DESCRIPTION
 
-Sisimai::Lhost::MessageLabs parses a bounce email which created by C<Symantec.cloud>:
-formerly known as C<MessageLabs>.
-Methods in the module are called from only Sisimai::Message.
+C<Sisimai::Lhost::MessageLabs> decodes a bounce email which created by Email Security (formerly Messaging
+Security) L<https://www.broadcom.com/products/cybersecurity/email> (formerly Symantec.cloud: formerly
+known as MessageLabs L<https://messagelabs.com>.
+Methods in the module are called from only C<Sisimai::Message>.
 
 =head1 CLASS METHODS
 
@@ -145,10 +144,10 @@ C<description()> returns description string of this module.
 
     print Sisimai::Lhost::MessageLabs->description;
 
-=head2 C<B<make(I<header data>, I<reference to body string>)>>
+=head2 C<B<inquire(I<header data>, I<reference to body string>)>>
 
-C<make()> method parses a bounced email and return results as a array reference.
-See Sisimai::Message for more details.
+C<inquire()> method decodes a bounced email and return results as a array reference.
+See C<Sisimai::Message> for more details.
 
 =head1 AUTHOR
 
@@ -156,7 +155,7 @@ azumakuniyuki
 
 =head1 COPYRIGHT
 
-Copyright (C) 2014-2020 azumakuniyuki, All rights reserved.
+Copyright (C) 2014-2021,2023,2024 azumakuniyuki, All rights reserved.
 
 =head1 LICENSE
 
